Config

Struct Config 

pub struct Config { /* private fields */ }
The resolved configuration for a Lux session. Can be constructed via ConfigBuilder, which supports layering multiple configuration sources (config file, CLI flags, environment variables).

Implementations

Source

impl Config

pub fn with_lua_version(self, lua_version: LuaVersion) -> Self

Create a copy of this config for the specified Lua version

pub fn with_tree(self, tree: PathBuf) -> Self

Create a copy of this config with the specified install tree

pub fn server(&self) -> &Url

The luarocks repository server

pub fn extra_servers(&self) -> &Vec<Url>

Additional luarocks repository servers

pub fn enabled_dev_servers(&self) -> Result<Vec<Url>, ConfigError>

Enabled luarocks repository servers that provide dev/scm rocks

pub fn namespace(&self) -> Option<&String>

The luarocks server namespace to use

pub fn lua_dir(&self) -> Option<&PathBuf>

The directory in which to install Lua{n} if not found

pub fn lua_version(&self) -> Option<&LuaVersion>

pub fn user_tree(&self, version: LuaVersion) -> Result<Tree, TreeError>

The tree in which to install rocks. If installing packages for a project, use Project::tree instead.

pub fn verbose(&self) -> bool

Whether to display verbose output of commands executed

pub fn no_progress(&self) -> bool

Whether to disable printing progress bars and spinners

pub fn no_prompt(&self) -> bool

Whether to skip prompts, selecting the default option

pub fn timeout(&self) -> &Duration

Timeout on network operations, in seconds. 0 means no timeout (wait forever).

pub fn max_jobs(&self) -> usize

Maximum buffer size for parallel jobs, such as downloading rockspecs and installing rocks. 0 means no limit.

pub fn make_cmd(&self) -> String

Command to use for running make builds

pub fn cmake_cmd(&self) -> String

Command to use for running cmake builds

pub fn variables(&self) -> &HashMap<String, String>

Variable names, mapped to their values. Lux populates variables in the lux.toml and in RockSpecs with these before building.

pub fn external_deps(&self) -> &ExternalDependencySearchConfig

pub fn entrypoint_layout(&self) -> &RockLayoutConfig

The rock layout for entrypoints of new install trees. Does not affect existing install trees or dependency rock layouts.

pub fn cache_dir(&self) -> &PathBuf

The Lux cache directory

pub fn data_dir(&self) -> &PathBuf

The Lux data directory

pub fn vendor_dir(&self) -> Option<&PathBuf>

Specifies a directory with locally vendored sources and RockSpecs. When building or installing a package with this flag, Lux will fetch sources from the instead of from a remote server.

pub fn user_agent(&self) -> &str

The user agent to use when making web requests.

pub fn generate_luarc(&self) -> bool

Whether to generate a .luarc.json on build.

pub fn luarc_file_name(&self) -> &str

pub fn wrap_bin_scripts(&self) -> bool

Whether to wrap installed Lua bin scripts to be executed with the detected or configured Lua installation. If true, individual rocks can still disable wrapping of their own bin scripts.