ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Incrementally builds a Config by layering configuration sources.

Implementations

Source

impl ConfigBuilder

A builder for the lux Config.

pub fn new() -> Result<Self, ConfigError>

Create a new ConfigBuilder by deserializing from a config file if present, or otherwise by instantiating the default config.

pub fn config_file() -> Result<PathBuf, NoValidHomeDirectory>

Get the path to the lux config file.

pub fn dev(self, dev: Option<bool>) -> Self

Whether to enable development packages Default: false

pub fn server(self, server: Option<Url>) -> Self

Fetch rocks/rockspecs from this luarocks server Default: "https://luarocks.org/"

pub fn extra_servers(self, extra_servers: Option<Vec<Url>>) -> Self

Fetch rocks/rockspecs from these servers in addition to the main server

pub fn namespace(self, namespace: Option<String>) -> Self

The luarocks server namespace to use

pub fn lua_dir(self, lua_dir: Option<PathBuf>) -> Self

The directory in which to install Lua if not found

pub fn lua_version(self, lua_version: Option<LuaVersion>) -> Self

Which Lua version to use. Default: The installed Lua version, if detected

pub fn user_tree(self, tree: Option<PathBuf>) -> Self

Which tree to operate on

pub fn variables(self, variables: Option<HashMap<String, String>>) -> Self

Variable names, mapped to their values. Lux populates variables in the lux.toml and in RockSpecs with these before building.

pub fn verbose(self, verbose: Option<bool>) -> Self

Whether to display verbose output of commands executed. Default: false

pub fn no_progress(self, no_progress: Option<bool>) -> Self

Whether to disable printing progress bars and spinners Default: false

pub fn no_prompt(self, no_prompt: Option<bool>) -> Self

Whether to disable user prompts Default: false

pub fn timeout(self, timeout: Option<Duration>) -> Self

Timeout on network operations, in seconds. 0 means no timeout (wait forever). Default: 30 s

pub fn max_jobs(self, max_jobs: Option<usize>) -> Self

Maximum buffer size for parallel jobs, such as downloading rockspecs and installing rocks. 0 means no limit. Default: 0

pub fn cache_dir(self, cache_dir: Option<PathBuf>) -> Self

The cache directory, e.g. for luarocks manifests.

pub fn data_dir(self, data_dir: Option<PathBuf>) -> Self

The data directory, in which the default user install tree resides.

pub fn vendor_dir(self, vendor_dir: Option<PathBuf>) -> Self

Specifies a directory with locally vendored sources and RockSpecs. When building or installing a package with this flag, Lux will fetch sources from the instead of from a remote server.

pub fn entrypoint_layout(self, rock_layout: RockLayoutConfig) -> Self

The rock layout for entrypoints of new install trees. Does not affect existing install trees or dependency rock layouts.

pub fn user_agent(self, user_agent: Option<String>) -> Self

The user agent to set when making web requests. Default: “lux-lib/”.

pub fn generate_luarc(self, generate: Option<bool>) -> Self

Whether to generate a .luarc.json on build. Default: true

pub fn luarc_file_name(self, file: Option<String>) -> Self

Lua runtime configuration file name Default: .luarc.json

pub fn wrap_bin_scripts(self, generate: Option<bool>) -> Self

Whether to wrap installed Lua bin scripts to be executed with the detected or configured Lua installation. Setting this to false disables wrapping globally. If set to true, individual rocks can still disable wrapping of their own bin scripts. Default: true.

pub fn build(self) -> Result<Config, ConfigError>