Module lockfile

Module lockfile 

Structs

FlushLockfileError
LocalPackage
A locally installed rock
LocalPackageHashes
LocalPackageId
ID of a local package, a hash that is comprised of:
LocalPackageLockTypeIter
An iterator over the variants of LocalPackageLockType
Lockfile
A lockfile for an install tree
LockfileGuard
Flushes a lockfile automatically when it goes out of scope
ProjectLockfileGuard
ReadOnly
ReadWrite
WorkspaceLockfile
A lockfile for a Lua project

Enums

LocalPackageLockType
LockConstraint
LockConstraintParseError
LockfileError
LockfileIntegrityError
OptState
PinnedState

Traits

LockfilePermissions