pub struct LocalPackageId(/* private fields */);Implementations
Sourceimpl LocalPackageId
impl LocalPackageId
pub fn new( name: &PackageName, version: &PackageVersion, pinned: PinnedState, opt: OptState, constraint: LockConstraint, ) -> Self
Sourcepub unsafe fn from_unchecked(str: String) -> Self
pub unsafe fn from_unchecked(str: String) -> Self
Constructs a package ID from a hashed string.
Safety
Ensure that the hash you are providing to this function is not malformed and resolves to a valid package ID for the target tree you are working with.