pub struct Lockfile<P: LockfilePermissions> { /* private fields */ }Expand description
A lockfile for an install tree
Implementations
Sourceimpl<P: LockfilePermissions> Lockfile<P>
impl<P: LockfilePermissions> Lockfile<P>
pub fn version(&self) -> &String
pub fn rocks(&self) -> &BTreeMap<LocalPackageId, LocalPackage>
pub fn is_dependency(&self, package: &LocalPackageId) -> bool
pub fn is_entrypoint(&self, package: &LocalPackageId) -> bool
pub fn entry_type(&self, package: &LocalPackageId) -> bool
pub fn get(&self, id: &LocalPackageId) -> Option<&LocalPackage>
Sourcepub unsafe fn get_unchecked(&self, id: &LocalPackageId) -> &LocalPackage
pub unsafe fn get_unchecked(&self, id: &LocalPackageId) -> &LocalPackage
Unsafe because this assumes a prior check if the package is present
Safety
Ensure that the package is present in the lockfile before calling this function.
Sourceimpl Lockfile<ReadOnly>
impl Lockfile<ReadOnly>
Sourcepub fn load(
filepath: PathBuf,
expected_rock_layout: Option<&RockLayoutConfig>,
) -> Result<Lockfile<ReadOnly>, LockfileError>
pub fn load( filepath: PathBuf, expected_rock_layout: Option<&RockLayoutConfig>, ) -> Result<Lockfile<ReadOnly>, LockfileError>
Load a Lockfile, failing if none exists.
If expected_rock_layout is Some, this fails if the rock layouts don’t match
Sourcepub fn write_guard(self) -> LockfileGuard
pub fn write_guard(self) -> LockfileGuard
Creates a lockfile guard, flushing the lockfile automatically once the guard goes out of scope.