pub enum BuildBackendSpec {
Builtin(BuiltinBuildSpec),
Make(MakeBuildSpec),
CMake(CMakeBuildSpec),
Command(CommandBuildSpec),
LuaRock(String),
RustMlua(RustMluaBuildSpec),
TreesitterParser(TreesitterParserBuildSpec),
Source,
}Expand description
Encodes extra information about each backend.
When selecting a backend, one may provide extra parameters
to build = { ... } in order to further customize the behaviour of the build step.
Luarocks provides several default build types, these are also reflected in lux
for compatibility.
Variants
Builtin(BuiltinBuildSpec)
Make(MakeBuildSpec)
CMake(CMakeBuildSpec)
Command(CommandBuildSpec)
LuaRock(String)
RustMlua(RustMluaBuildSpec)
TreesitterParser(TreesitterParserBuildSpec)
Build from the source rockspec, if present. Otherwise, fall back to the builtin build and copy all directories. This is currently unimplemented by luarocks, but we don’t ever publish rockspecs that implement this. It could be implemented as a custom build backend.