pub enum ModuleSpec {
SourcePath(PathBuf),
SourcePaths(Vec<PathBuf>),
ModulePaths(ModulePaths),
}Variants
SourcePath(PathBuf)
Pathnames of Lua files or C sources, for modules based on a single source file.
SourcePaths(Vec<PathBuf>)
Pathnames of C sources of a simple module written in C composed of multiple files.
ModulePaths(ModulePaths)
Implementations
Sourceimpl ModuleSpec
impl ModuleSpec
pub fn from_internal( internal: ModuleSpecInternal, ) -> Result<ModuleSpec, ModulePathsMissingSources>