pub enum PlatformIdentifier {
Unix,
Windows,
Win32,
Cygwin,
MacOSX,
Linux,
FreeBSD,
Unknown(String),
}Expand description
Identifier by a platform.
The PartialOrd instance views more specific platforms as Greater
Variants
Implementations
Sourceimpl PlatformIdentifier
impl PlatformIdentifier
Sourcepub fn get_subsets(&self) -> Vec<Self>
pub fn get_subsets(&self) -> Vec<Self>
Get identifiers that are a subset of this identifier. For example, Unix is a subset of Linux
Sourcepub fn get_extended_platforms(&self) -> Vec<Self>
pub fn get_extended_platforms(&self) -> Vec<Self>
Get identifiers that are an extension of this identifier. For example, Linux is an extension of Unix