pub struct BuildSpec {
pub build_backend: Option<BuildBackendSpec>,
pub install: InstallSpec,
pub copy_directories: Vec<PathBuf>,
pub patches: HashMap<PathBuf, String>,
}Expand description
The build specification for a given rock, serialized from rockspec.build = { ... }.
See the rockspec format for more info.
Fields
build_backend: Option<BuildBackendSpec>Determines the build backend to use.
install: InstallSpecA set of instructions on how/where to copy files from the project.
copy_directories: Vec<PathBuf>A list of directories that should be copied as-is into the resulting rock.
patches: HashMap<PathBuf, String>A list of patches to apply to the project before packaging it.