pub struct InstallSpec {
pub lua: HashMap<LuaModule, PathBuf>,
pub lib: HashMap<String, PathBuf>,
pub conf: HashMap<String, PathBuf>,
pub bin: HashMap<String, PathBuf>,
}Expand description
For packages which don’t provide means to install modules and expect the user to copy the .lua or library files by hand to the proper locations. This struct contains categories of files. Each category is itself a table, where the array part is a list of filenames to be copied. For module directories only, in the hash part, other keys are identifiers in Lua module format, to indicate which subdirectory the file should be copied to. For example, build.install.lua = {[“foo.bar”] = {“src/bar.lua”}} will copy src/bar.lua to the foo directory under the rock’s Lua files directory.
Fields
lua: HashMap<LuaModule, PathBuf>Lua modules written in Lua.
lib: HashMap<String, PathBuf>Dynamic libraries implemented compiled Lua modules.
conf: HashMap<String, PathBuf>Configuration files.
bin: HashMap<String, PathBuf>Lua command-line scripts.