pub struct MakeBuildSpec {
pub makefile: PathBuf,
pub build_target: Option<String>,
pub build_pass: bool,
pub install_target: String,
pub install_pass: bool,
pub build_variables: HashMap<String, String>,
pub install_variables: HashMap<String, String>,
pub variables: HashMap<String, String>,
}Fields
makefile: PathBufMakefile to be used. Default is “Makefile” on Unix variants and “Makefile.win” under Win32.
build_target: Option<String>build_pass: boolWhether to perform a make pass on the target indicated by build_target.
Default is true (i.e., to run make).
install_target: StringDefault is “install”
install_pass: boolWhether to perform a make pass on the target indicated by install_target.
Default is true (i.e., to run make).
build_variables: HashMap<String, String>Assignments to be passed to make during the build pass
install_variables: HashMap<String, String>Assignments to be passed to make during the install pass
variables: HashMap<String, String>Assignments to be passed to make during both passes