pub struct RockDescription {
pub summary: Option<String>,
pub detailed: Option<String>,
pub license: Option<String>,
pub homepage: Option<Url>,
pub issues_url: Option<String>,
pub maintainer: Option<String>,
pub labels: Vec<String>,
}Fields
summary: Option<String>A one-line description of the package.
detailed: Option<String>A longer description of the package.
license: Option<String>The license used by the package.
homepage: Option<Url>An URL for the project. This is not the URL for the tarball, but the address of a website.
issues_url: Option<String>An URL for the project’s issue tracker.
maintainer: Option<String>Contact information for the rockspec maintainer.
labels: Vec<String>A list of short strings that specify labels for categorization of this rock.