pub struct RustMluaBuildSpec {
pub modules: HashMap<String, PathBuf>,
pub target_path: PathBuf,
pub default_features: bool,
pub features: Vec<String>,
pub cargo_extra_args: Vec<String>,
pub include: HashMap<PathBuf, PathBuf>,
}Fields
modules: HashMap<String, PathBuf>Keys are module names in the format normally used by the require() function.
values are the library names in the target directory (without the lib prefix).
target_path: PathBufSet if the cargo target directory is not in the source root.
default_features: boolIf set to false pass --no-default-features to cargo.
features: Vec<String>Pass additional features
cargo_extra_args: Vec<String>Additional flags to be passed in the cargo invocation.
include: HashMap<PathBuf, PathBuf>Copy additional files to the lua directory.
Keys are the sources, values the destinations (relative to the lua directory).