Module operations

Module operations 

Re-exports

pub use install::*;

Modules

install

Structs

BuildLua
BuildLuaBuilder
Use builder syntax to set the inputs and finish with _build().
BuildWorkspace
BuildWorkspaceBuilder
Use builder syntax to set the inputs and finish with _build().
Download
Builder for a rock downloader.
DownloadedPackedRock
DownloadedPackedRockBytes
DownloadedRockspec
Exec
Rocks package runner, providing fine-grained control over how a package should be run.
ExecBuilder
Use builder syntax to set the inputs and finish with _exec().
FetchSrc
A rocks package source fetcher, providing fine-grained control over how a package should be fetched.
FetchSrcBuilder
Use builder syntax to set the inputs and finish with _build().
Pack
A binary rock packer
PackBuilder
Use builder syntax to set the inputs and finish with _build().
Run
RunBuilder
Use builder syntax to set the inputs and finish with _build().
RunCommand
RunCommandError
RunLua
RunLuaBuilder
Use builder syntax to set the inputs and finish with _build().
Sync
A rocks sync builder, for synchronising a tree with a lockfile.
SyncBuilder
Use builder syntax to set the inputs and finish with _build().
SyncReport
Test
TestBuilder
Use builder syntax to set the inputs and finish with _run().
Uninstall
UninstallBuilder
Use builder syntax to set the inputs and finish with _build().
Update
A rocks package updater, providing fine-grained control over how packages should be updated. Can update multiple packages in parallel.
UpdateBuilder
Use builder syntax to set the inputs and finish with _update().
Vendor
Vendor a project’s dependencies into the specified directory at <vendor_dir>. After this command completes the vendor directory specified by <vendor_dir> will contain all remote sources from dependencies specified.
VendorBuilder
Use builder syntax to set the inputs and finish with _build().

Enums

BuildLuaError
BuildWorkspaceError
DownloadRockspecError
DownloadSrcRockError
ExecError
FetchSrcError
FetchSrcRockError
GenLuaRcError
InstallCommandError
InstallTestDependenciesError
PackError
PinError
RemoveError
RunError
RunLuaError
RunTestsError
SearchAndDownloadError
SyncError
TestEnv
UnpackError
UpdateError
VendorError
VendorTarget

Functions

set_pinned_state
unpack_src_rock