pub struct DistProjectBinBuilder<'a, T, S: State = Empty>where
T: InstallTree,{ /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with _build().
Implementations
Sourceimpl<'a, T, S: State> DistProjectBinBuilder<'a, T, S>where
T: InstallTree,
impl<'a, T, S: State> DistProjectBinBuilder<'a, T, S>where
T: InstallTree,
Sourcepub fn project(
self,
value: &'a Project,
) -> DistProjectBinBuilder<'a, T, SetProject<S>>where
S::Project: IsUnset,
pub fn project(
self,
value: &'a Project,
) -> DistProjectBinBuilder<'a, T, SetProject<S>>where
S::Project: IsUnset,
Required.
The project to compile.
Sourcepub fn config(
self,
value: &'a Config,
) -> DistProjectBinBuilder<'a, T, SetConfig<S>>where
S::Config: IsUnset,
pub fn config(
self,
value: &'a Config,
) -> DistProjectBinBuilder<'a, T, SetConfig<S>>where
S::Config: IsUnset,
Required.
Sourcepub fn tree(self, value: &'a T) -> DistProjectBinBuilder<'a, T, SetTree<S>>where
S::Tree: IsUnset,
pub fn tree(self, value: &'a T) -> DistProjectBinBuilder<'a, T, SetTree<S>>where
S::Tree: IsUnset,
Required.
Tree in which to install the project before compiling.
Sourcepub fn output(
self,
value: PathBuf,
) -> DistProjectBinBuilder<'a, T, SetOutput<S>>where
S::Output: IsUnset,
pub fn output(
self,
value: PathBuf,
) -> DistProjectBinBuilder<'a, T, SetOutput<S>>where
S::Output: IsUnset,
Sourcepub fn maybe_output(
self,
value: Option<PathBuf>,
) -> DistProjectBinBuilder<'a, T, SetOutput<S>>where
S::Output: IsUnset,
pub fn maybe_output(
self,
value: Option<PathBuf>,
) -> DistProjectBinBuilder<'a, T, SetOutput<S>>where
S::Output: IsUnset,
Sourcepub fn progress(
self,
value: Arc<Progress<MultiProgress>>,
) -> DistProjectBinBuilder<'a, T, SetProgress<S>>where
S::Progress: IsUnset,
pub fn progress(
self,
value: Arc<Progress<MultiProgress>>,
) -> DistProjectBinBuilder<'a, T, SetProgress<S>>where
S::Progress: IsUnset,
Sourcepub fn maybe_progress(
self,
value: Option<Arc<Progress<MultiProgress>>>,
) -> DistProjectBinBuilder<'a, T, SetProgress<S>>where
S::Progress: IsUnset,
pub fn maybe_progress(
self,
value: Option<Arc<Progress<MultiProgress>>>,
) -> DistProjectBinBuilder<'a, T, SetProgress<S>>where
S::Progress: IsUnset,
Sourceimpl<T, State> DistProjectBinBuilder<'_, T, State>
impl<T, State> DistProjectBinBuilder<'_, T, State>
pub async fn compile(self) -> Result<PathBuf, DistProjectBinError>