pub struct Download<'a> { /* private fields */ }Expand description
Builder for a rock downloader.
Implementations
Sourceimpl<'a> Download<'a>
impl<'a> Download<'a>
Sourcepub fn new(
package_req: &'a PackageReq,
config: &'a Config,
progress: &'a Progress<ProgressBar>,
) -> Self
pub fn new( package_req: &'a PackageReq, config: &'a Config, progress: &'a Progress<ProgressBar>, ) -> Self
Construct a new .src.rock downloader.
Sourcepub fn package_db(self, package_db: &'a RemotePackageDB) -> Self
pub fn package_db(self, package_db: &'a RemotePackageDB) -> Self
Sets the package database to use for searching for packages. Instantiated from the config if not set.
Sourcepub async fn download_rockspec(
self,
) -> Result<DownloadedRockspec, SearchAndDownloadError>
pub async fn download_rockspec( self, ) -> Result<DownloadedRockspec, SearchAndDownloadError>
Download the package’s Rockspec.
Sourcepub async fn download_src_rock_to_file(
self,
destination_dir: Option<PathBuf>,
) -> Result<DownloadedPackedRock, SearchAndDownloadError>
pub async fn download_src_rock_to_file( self, destination_dir: Option<PathBuf>, ) -> Result<DownloadedPackedRock, SearchAndDownloadError>
Download a .src.rock to a file.
destination_dir defaults to the current working directory if not set.
Sourcepub async fn search_and_download_src_rock(
self,
) -> Result<DownloadedPackedRockBytes, SearchAndDownloadError>
pub async fn search_and_download_src_rock( self, ) -> Result<DownloadedPackedRockBytes, SearchAndDownloadError>
Search for a .src.rock and download it to memory.