pub struct UninstallBuilder<'a, S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with _build().
Implementations
Sourceimpl<'a, S: State> UninstallBuilder<'a, S>
impl<'a, S: State> UninstallBuilder<'a, S>
Sourcepub fn config(self, value: &'a Config) -> UninstallBuilder<'a, SetConfig<S>>where
S::Config: IsUnset,
pub fn config(self, value: &'a Config) -> UninstallBuilder<'a, SetConfig<S>>where
S::Config: IsUnset,
Required.
Sourcepub fn progress(
self,
value: Arc<Progress<MultiProgress>>,
) -> UninstallBuilder<'a, SetProgress<S>>where
S::Progress: IsUnset,
pub fn progress(
self,
value: Arc<Progress<MultiProgress>>,
) -> UninstallBuilder<'a, SetProgress<S>>where
S::Progress: IsUnset,
Sourcepub fn maybe_progress(
self,
value: Option<Arc<Progress<MultiProgress>>>,
) -> UninstallBuilder<'a, SetProgress<S>>where
S::Progress: IsUnset,
pub fn maybe_progress(
self,
value: Option<Arc<Progress<MultiProgress>>>,
) -> UninstallBuilder<'a, SetProgress<S>>where
S::Progress: IsUnset,
Sourcepub fn tree(self, value: Tree) -> UninstallBuilder<'a, SetTree<S>>where
S::Tree: IsUnset,
pub fn tree(self, value: Tree) -> UninstallBuilder<'a, SetTree<S>>where
S::Tree: IsUnset,
Sourcepub fn maybe_tree(self, value: Option<Tree>) -> UninstallBuilder<'a, SetTree<S>>where
S::Tree: IsUnset,
pub fn maybe_tree(self, value: Option<Tree>) -> UninstallBuilder<'a, SetTree<S>>where
S::Tree: IsUnset,
Sourceimpl<'a, State> UninstallBuilder<'a, State>where
State: State,
impl<'a, State> UninstallBuilder<'a, State>where
State: State,
Sourcepub fn packages<I>(self, packages: I) -> Selfwhere
I: IntoIterator<Item = LocalPackageId>,
pub fn packages<I>(self, packages: I) -> Selfwhere
I: IntoIterator<Item = LocalPackageId>,
Add packages to remove.
Sourcepub fn package(self, package: LocalPackageId) -> Self
pub fn package(self, package: LocalPackageId) -> Self
Add a package to the set of packages to remove.
Sourceimpl<'a, State> UninstallBuilder<'a, State>where
State: State + IsComplete,
impl<'a, State> UninstallBuilder<'a, State>where
State: State + IsComplete,
Sourcepub async fn remove(self) -> Result<(), RemoveError>
pub async fn remove(self) -> Result<(), RemoveError>
Remove the packages.