pub enum PackageVersion {
SemVer(SemVer),
DevVer(DevVer),
StringVer(StringVer),
}Variants
SemVer(SemVer)
SemVer version as defined by https://semver.org, but a bit more lenient for compatibility with luarocks
DevVer(DevVer)
A known Dev version
StringVer(StringVer)
An arbitrary string version. Yes, luarocks-site allows arbitrary string versions in the root manifest ┻━┻ ︵ヽ(`Д´)ノ︵ ┻━┻
Implementations
Sourceimpl PackageVersion
impl PackageVersion
pub fn parse(text: &str) -> Result<Self, PackageVersionParseError>
Sourcepub fn into_version_req(&self) -> PackageVersionReq
pub fn into_version_req(&self) -> PackageVersionReq
Note that this loses the specrev information.