pub struct PackageReq { /* private fields */ }Expand description
A lua package requirement with a name and an optional version requirement.
Implementations
Sourceimpl PackageReq
impl PackageReq
pub fn new( name: String, version: Option<String>, ) -> Result<Self, PackageVersionReqError>
Sourcepub unsafe fn new_unchecked(name: String, version: Option<String>) -> Self
pub unsafe fn new_unchecked(name: String, version: Option<String>) -> Self
Safety
Call this only if you are absolutely sure that a PackageReq can be parsed from the arguments.
Calling this with invalid arguments is undefined behaviour.
pub fn parse(pkg_constraints: &str) -> Result<Self, PackageReqParseError>
pub fn name(&self) -> &PackageName
pub fn version_req(&self) -> &PackageVersionReq
Sourcepub fn matches(&self, package: &PackageSpec) -> bool
pub fn matches(&self, package: &PackageSpec) -> bool
Evaluate whether the given package satisfies the package requirement
given by self.