Module project

Module project 

Re-exports

pub use project_toml::PROJECT_TOML;

Modules

project_toml
Structs and utilities for lux.toml

Structs

Project
Lux project, with methods for managing dependencies, etc.
ProjectRoot
A newtype for the project root directory. This is used to ensure that the project root is a valid project directory.
TomlDeError
A wrapper around toml::de::Error plus the original source code and the byte range where the error occurred so that miette can render the failure with line numbers and context.

Enums

IntoLocalRockspecError
IntoRemoteRockspecError
PinError
ProjectEditError
ProjectError

Constants

EXTRA_ROCKSPEC