pub struct LocalProjectToml { /* private fields */ }Expand description
The lux.toml file, after being properly deserialized.
This struct may be used to build a local version of a project.
To build a rockspec, use RemoteProjectToml.
Implementations
Sourceimpl LocalProjectToml
impl LocalProjectToml
pub fn run(&self) -> Option<&PerPlatform<RunSpec>>
Sourcepub fn to_lua_rockspec(&self) -> Result<LocalLuaRockspec, LuaRockspecError>
pub fn to_lua_rockspec(&self) -> Result<LocalLuaRockspec, LuaRockspecError>
Convert this project TOML to a Lua rockspec. Fails if there is no valid project root or if there are off-spec dependencies.