pub struct PartialProjectToml { /* private fields */ }Expand description
The lux.toml file.
The only required fields are package and build, which are required to build a project using lux build.
The rest of the fields are optional, but are required to build a rockspec.
Implementations
Sourceimpl PartialProjectToml
impl PartialProjectToml
Sourcepub fn into_local(
&self,
) -> Result<LocalProjectToml, LocalProjectTomlValidationError>
pub fn into_local( &self, ) -> Result<LocalProjectToml, LocalProjectTomlValidationError>
Convert the PartialProjectToml struct into a LocalProjectToml struct, making
it ready to be used for building a project.
Sourcepub fn into_remote(
&self,
specrev: Option<SpecRev>,
) -> Result<RemoteProjectToml, RemoteProjectTomlValidationError>
pub fn into_remote( &self, specrev: Option<SpecRev>, ) -> Result<RemoteProjectToml, RemoteProjectTomlValidationError>
Convert the PartialProjectToml struct into a RemoteProjectToml struct, making
it ready to be serialized into a rockspec.
A source must be provided for the rockspec to be valid.
pub fn package(&self) -> &PackageName
Sourcepub fn version(&self) -> Result<PackageVersion, GenerateVersionError>
pub fn version(&self) -> Result<PackageVersion, GenerateVersionError>
Returns the current package version, which may be generated from a template
Sourcepub fn merge(self, other: PartialLuaRockspec) -> Self
pub fn merge(self, other: PartialLuaRockspec) -> Self
Merge the ProjectToml struct with an unvalidated LuaRockspec.
The final merged struct can then be validated.