Module tree

Module tree 

Structs

FlatDistTree
A staging tree with a flat hierarchy for distribution outside of Lux. When dropped, tries to remove all build artifacts that are not meant to be distributed, as well as the etc directory (failing silently if any artifacts cannot be removed). Unlike a regular Lux tree, conflicting packages are not supported.
RockLayout
Change-agnostic way of referencing various paths for a rock.
Tree

Enums

EntryType
RockMatches
TreeError

Traits

InstallTree
A tree is a collection of files where installed rocks are located.