FlatDistTree

Struct FlatDistTree 

pub struct FlatDistTree(/* private fields */);
A staging tree with a flat hierarchy for distribution outside of Lux. When dropped, tries to remove all build artifacts that are not meant to be distributed, as well as the etc directory (failing silently if any artifacts cannot be removed). Unlike a regular Lux tree, conflicting packages are not supported.

Implementations

Source

impl FlatDistTree

pub fn new( root: PathBuf, version: LuaVersion, config: &Config, ) -> Result<Self, TreeError>