pub struct RockLayout {
pub rock_path: PathBuf,
pub etc: PathBuf,
pub lib: PathBuf,
pub src: PathBuf,
pub bin: PathBuf,
pub conf: PathBuf,
pub doc: PathBuf,
}Expand description
Change-agnostic way of referencing various paths for a rock.
Fields
rock_path: PathBufThe local installation directory.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(PREFIX).
etc: PathBufThe etc directory, containing resources.
lib: PathBufThe lib directory, containing native libraries.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(LIBDIR).
src: PathBufThe src directory, containing Lua sources.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(LUADIR).
bin: PathBufThe bin directory, containing executables.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(BINDIR).
This points to a global binary path at the root of the current tree by default.
conf: PathBufThe etc/conf directory, containing configuration files.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(CONFDIR).
doc: PathBufThe etc/doc directory, containing documentation files.
Can be substituted in a rockspec’s build.build_variables and build.install_variables
using $(DOCDIR).
Implementations
Sourceimpl RockLayout
impl RockLayout
pub fn rockspec_path(&self) -> PathBuf