pub struct Tree { /* private fields */ }Expand description
A tree is a collection of files where installed rocks are located.
lux diverges from the traditional hierarchy employed by luarocks.
Instead, we opt for a much simpler approach:
- /rocks/
- contains rocks - /rocks/
/ /etc - documentation and supplementary files for the rock - /rocks/
/ /lib - shared libraries (.so files) - /rocks/
/ /src - library code for the rock - /bin - binary files produced by various rocks
Implementations
Sourceimpl Tree
impl Tree
pub fn list(&self) -> Result<HashMap<PackageName, Vec<LocalPackage>>, TreeError>
pub fn as_rock_list(&self) -> Result<Vec<LocalPackage>, TreeError>
Sourceimpl Tree
impl Tree
pub fn version(&self) -> &LuaVersion
pub fn root_for(&self, package: &LocalPackage) -> PathBuf
pub fn bin(&self) -> PathBuf
pub fn match_rocks(&self, req: &PackageReq) -> Result<RockMatches, TreeError>
pub fn match_rocks_and<F>( &self, req: &PackageReq, filter: F, ) -> Result<RockMatches, TreeError>
Sourcepub fn installed_rock_layout(
&self,
package: &LocalPackage,
) -> Result<RockLayout, TreeError>
pub fn installed_rock_layout( &self, package: &LocalPackage, ) -> Result<RockLayout, TreeError>
Get the RockLayout for an installed package.
Sourcepub fn entrypoint_layout(&self, package: &LocalPackage) -> RockLayout
pub fn entrypoint_layout(&self, package: &LocalPackage) -> RockLayout
Create a RockLayout for an entrypoint
Sourcepub fn dependency_layout(&self, package: &LocalPackage) -> RockLayout
pub fn dependency_layout(&self, package: &LocalPackage) -> RockLayout
Create a RockLayout for a dependency
Sourcepub fn entrypoint(&self, package: &LocalPackage) -> Result<RockLayout>
pub fn entrypoint(&self, package: &LocalPackage) -> Result<RockLayout>
Create a RockLayout for an entrypoint package, creating the lib and src directories.
Sourcepub fn dependency(&self, package: &LocalPackage) -> Result<RockLayout>
pub fn dependency(&self, package: &LocalPackage) -> Result<RockLayout>
Create a RockLayout for a dependency package, creating the lib and src directories.
pub fn lockfile(&self) -> Result<Lockfile<ReadOnly>, TreeError>
Sourcepub fn lockfile_path(&self) -> PathBuf
pub fn lockfile_path(&self) -> PathBuf
Get this tree’s lockfile path.
Sourcepub fn test_tree(&self, config: &Config) -> Result<Self, TreeError>
pub fn test_tree(&self, config: &Config) -> Result<Self, TreeError>
The tree in which to install test dependencies
Sourcepub fn build_tree(&self, config: &Config) -> Result<Self, TreeError>
pub fn build_tree(&self, config: &Config) -> Result<Self, TreeError>
The tree in which to install build dependencies