Workspace

Struct Workspace 

pub struct Workspace { /* private fields */ }

Implementations

Source

impl Workspace

pub fn current() -> Result<Option<Self>, WorkspaceError>

pub fn current_or_err() -> Result<Self, WorkspaceError>

pub fn root(&self) -> &WorkspaceRoot

The path where the root lux.toml resides.

pub fn members(&self) -> &NonEmpty<Project>

The members of this workspace.

pub fn members_mut(&mut self) -> &mut NonEmpty<Project>

Mutable reference to the members of this workspace.

pub fn single_member_or_select( &self, name: &Option<PackageName>, ) -> Result<&Project, WorkspaceError>

Get a workspace member, defaulting to the first one if none is specified. Fails if a package name is specified, but not found.

pub fn single_member_or_select_mut( &mut self, package: &Option<PackageName>, ) -> Result<&mut Project, WorkspaceError>

Get a mutable workspace member, defaulting to the first one if none is specified. Fails if a package name is specified, but not found.

pub fn single_member(&self) -> Result<&Project, WorkspaceError>

Get the single member of this workspace, failing if it has multiple members.

pub fn single_member_mut(&mut self) -> Result<&mut Project, WorkspaceError>

Get the single mutable member of this workspace, failing if it has multiple members.

pub fn select_member( &self, package: &PackageName, ) -> Result<&Project, WorkspaceError>

Select a member of this workspace, failing if it is not found.

pub fn select_member_mut( &mut self, package: &PackageName, ) -> Result<&mut Project, WorkspaceError>

Select a mutable member of this workspace, failing if it is not found.

pub fn lockfile_path(&self) -> PathBuf

Get the lux.lock lockfile path.

pub fn lockfile(&self) -> Result<WorkspaceLockfile<ReadOnly>, WorkspaceError>

Get the lux.lock lockfile in the project root.

pub fn try_lockfile( &self, ) -> Result<Option<WorkspaceLockfile<ReadOnly>>, WorkspaceError>

Get the lux.lock lockfile in the project root, if present.

pub fn tree(&self, config: &Config) -> Result<Tree, WorkspaceTreeError>

pub fn lua_version( &self, config: &Config, ) -> Result<LuaVersion, LuaVersionError>

pub fn test_tree(&self, config: &Config) -> Result<Tree, WorkspaceTreeError>

pub fn build_tree(&self, config: &Config) -> Result<Tree, WorkspaceTreeError>

pub fn luarc_path(&self) -> PathBuf

Get the .luarc.json or .emmyrc.json path.

pub fn from_exact( start: impl AsRef<Path>, ) -> Result<Option<Self>, WorkspaceError>

pub fn from(start: impl AsRef<Path>) -> Result<Option<Self>, WorkspaceError>