pub struct ConfigBuilder { /* private fields */ }Implementations
Sourceimpl ConfigBuilder
A builder for the lux Config.
impl ConfigBuilder
A builder for the lux Config.
Sourcepub fn new() -> Result<Self, ConfigError>
pub fn new() -> Result<Self, ConfigError>
Create a new ConfigBuilder from a config file by deserializing from a config file
if present, or otherwise by instantiating the default config.
Sourcepub fn config_file() -> Result<PathBuf, NoValidHomeDirectory>
pub fn config_file() -> Result<PathBuf, NoValidHomeDirectory>
Get the path to the lux config file.
pub fn dev(self, dev: Option<bool>) -> Self
pub fn server(self, server: Option<Url>) -> Self
pub fn extra_servers(self, extra_servers: Option<Vec<Url>>) -> Self
pub fn only_sources(self, sources: Option<String>) -> Self
pub fn namespace(self, namespace: Option<String>) -> Self
pub fn lua_dir(self, lua_dir: Option<PathBuf>) -> Self
pub fn lua_version(self, lua_version: Option<LuaVersion>) -> Self
pub fn user_tree(self, tree: Option<PathBuf>) -> Self
pub fn variables(self, variables: Option<HashMap<String, String>>) -> Self
pub fn verbose(self, verbose: Option<bool>) -> Self
pub fn no_progress(self, no_progress: Option<bool>) -> Self
pub fn timeout(self, timeout: Option<Duration>) -> Self
pub fn max_jobs(self, max_jobs: Option<usize>) -> Self
pub fn cache_dir(self, cache_dir: Option<PathBuf>) -> Self
pub fn data_dir(self, data_dir: Option<PathBuf>) -> Self
pub fn vendor_dir(self, vendor_dir: Option<PathBuf>) -> Self
pub fn entrypoint_layout(self, rock_layout: RockLayoutConfig) -> Self
pub fn generate_luarc(self, generate: Option<bool>) -> Self
pub fn build(self) -> Result<Config, ConfigError>