pub struct LockfileGuard(/* private fields */);Methods from Deref<Target = Lockfile<ReadWrite>>
pub fn version(&self) -> &String
pub fn rocks(&self) -> &BTreeMap<LocalPackageId, LocalPackage>
pub fn is_dependency(&self, package: &LocalPackageId) -> bool
pub fn is_entrypoint(&self, package: &LocalPackageId) -> bool
pub fn entry_type(&self, package: &LocalPackageId) -> bool
pub fn get(&self, id: &LocalPackageId) -> Option<&LocalPackage>
Sourcepub unsafe fn get_unchecked(&self, id: &LocalPackageId) -> &LocalPackage
pub unsafe fn get_unchecked(&self, id: &LocalPackageId) -> &LocalPackage
Unsafe because this assumes a prior check if the package is present
Safety
Ensure that the package is present in the lockfile before calling this function.