Module lua_rockspec

Module lua_rockspec 

Structs

BuildSpec
The build specification for a given rock, serialized from build = { ... }.
BuiltinBuildSpec
BustedTestSpec
Specification for running a test suite with busted
CMakeBuildSpec
Specification for building a rock with the cmake build backend
CommandBuildSpec
Specification for building a rock with the command build backend
CommandTestSpec
Specification for running a test suite with a command
DeploySpec
An undocumented part of the rockspec format.
ExternalDependencySpec
Can be defined in a platform-agnostic manner
InstallSpec
For packages which don’t provide means to install modules and expect the user to copy the .lua or library files by hand to the proper locations. This struct contains categories of files. Each category is itself a table, where the array part is a list of filenames to be copied. For module directories only, in the hash part, other keys are identifiers in Lua module format, to indicate which subdirectory the file should be copied to. For example, lua = {[“foo.bar”] = “src/bar.lua”} will copy src/bar.lua to the foo directory under the rock’s Lua files directory.
InvalidRockspecFormat
LocalLuaRockspec
RockSpec for a local rock installation, deserialized from a .rockspec file
LocalRockSource
Specifies the source of a rock that has been fetched
LuaModule
LuaScriptTestSpec
Specification for running a test suite with a Lua script
MakeBuildSpec
Specification for building a rock with the make build backend
ModulePaths
Specification for building a Lua module from various sources
PartialLuaRockspec
Deserialized from a Lua .rockspec, not yet validated
PerPlatform
Data that that can vary per platform
PlatformIdentifierIter
An iterator over the variants of PlatformIdentifier
PlatformSupport
Used to specify which platforms a rock can be built for
RemoteLuaRockspec
RockSpec for a remote rock, deserialized from a .rockspec file
RemoteRockSource
Specifies the source of a remote rock to be fetched
RockDescription
A rock’s metadata, to be displayed on the remote package server
RockSourceMissingSource
RustMluaBuildSpec
Specification for building a rock with the rust-mlua build backend
TreesitterParserBuildSpec
Specification for building a rock with the treesitter-parser build backend

Enums

BuildBackendSpec
Encodes extra information about each backend. When selecting a backend, one may provide extra parameters to build = { ... } in order to further customize the behaviour of the build step.
BuildSpecInternalError
LuaRockspecError
LuaTableError
LuaVersionError
ModuleSpec
ParseLuaModuleError
PartialRockspecError
PlatformIdentifier
Identifier by a platform. The PartialOrd instance views more specific platforms as Greater
PlatformValidationError
RockSourceError
RockSourceSpec
Specifies a rock’s source
RockspecFormat
SourceUrlError
TestSpec
TestSpecDecodeError
TestSpecError

Traits

PartialOverride
PlatformOverridable