pub struct RustMluaBuildSpec {
pub modules: HashMap<String, PathBuf>,
pub target_path: PathBuf,
pub default_features: bool,
pub include: HashMap<PathBuf, PathBuf>,
pub features: Vec<String>,
}Fields
modules: HashMap<String, PathBuf>Keys are module names in the format normally used by the require() function.
values are the library names in the target directory.
target_path: PathBufSet if the cargo target directory is not in the source root.
default_features: boolIf set to false pass --no-default-features to cargo.
include: HashMap<PathBuf, PathBuf>Copy additional files to the lua directory.
Keys are the sources, values the destinations (relative to the lua directory).
features: Vec<String>Pass additional features