Re-exports
pub use install::*;
Modules
Structs
- Build
Lua - Build
LuaBuilder - Use builder syntax to set the inputs and finish with
_build(). - Build
Workspace - Build
Workspace Builder - Use builder syntax to set the inputs and finish with
_build(). - Download
- Builder for a rock downloader.
- Downloaded
Packed Rock - Downloaded
Packed Rock Bytes - Downloaded
Rockspec - Exec
- Rocks package runner, providing fine-grained control over how a package should be run.
- Exec
Builder - Use builder syntax to set the inputs and finish with
_exec(). - Fetch
Src - A rocks package source fetcher, providing fine-grained control over how a package should be fetched.
- Fetch
SrcBuilder - Use builder syntax to set the inputs and finish with
_build(). - Pack
- A binary rock packer
- Pack
Builder - Use builder syntax to set the inputs and finish with
_build(). - Run
- RunBuilder
- Use builder syntax to set the inputs and finish with
_build(). - RunCommand
- RunCommand
Error - RunLua
- RunLua
Builder - Use builder syntax to set the inputs and finish with
_build(). - Sync
- A rocks sync builder, for synchronising a tree with a lockfile.
- Sync
Builder - Use builder syntax to set the inputs and finish with
_build(). - Sync
Report - Test
- Test
Builder - Use builder syntax to set the inputs and finish with
_run(). - Uninstall
- Uninstall
Builder - Use builder syntax to set the inputs and finish with
_build(). - Update
- A rocks package updater, providing fine-grained control over how packages should be updated. Can update multiple packages in parallel.
- Update
Builder - Use builder syntax to set the inputs and finish with
_update(). - Vendor
- Vendor a project’s dependencies into the specified directory at
<vendor_dir>. After this command completes the vendor directory specified by<vendor_dir>will contain all remote sources from dependencies specified. - Vendor
Builder - Use builder syntax to set the inputs and finish with
_build().
Enums
- Build
LuaError - Build
Workspace Error - Download
Rockspec Error - Download
SrcRock Error - Exec
Error - Fetch
SrcError - Fetch
SrcRock Error - GenLua
RcError - Install
Command Error - Install
Test Dependencies Error - Pack
Error - PinError
- Remove
Error - RunError
- RunLua
Error - RunTests
Error - Search
AndDownload Error - Sync
Error - TestEnv
- Unpack
Error - Update
Error - Vendor
Error - Vendor
Target