Re-exports
pub use project_toml::PROJECT_TOML;
Modules
- project_
toml - Structs and utilities for
lux.toml
Structs
- Project
- Lux project, with methods for managing dependencies, etc.
- Project
Root - A newtype for the project root directory. This is used to ensure that the project root is a valid project directory.
- Toml
DeError - A wrapper around
toml::de::Errorplus the original source code and the byte range where the error occurred so thatmiettecan render the failure with line numbers and context.